+++
fragment = "content"
date = "2015-11-19"
weight = 100

title = "Hardware pack"
+++

# Hardware Pack

Hardware package contains specific packages for given hardware platform.
Most common software components we can find are boot loader, kernel and
specific drivers.

For creating hardware packages,
[linaro-image-tools](https://build.collabora.co.uk/package/show?package=linaro-image-tools&project=apertis%3Ainfrastructure)
is used along [configuration
file](https://git.apertis.org/cgit/apertis-image-customization.git/tree/customization/hwpack)
that can be found along image customization distribution package.

## Installing linaro-image-tools package

See [how to install image building
tools](https://wiki.apertis.org/mediawiki/index.php/Image_building#Image_Tools_Installation).

## Howto create a custom hardware pack

### Source Code

` git clone `<git://git.collabora.co.uk/git/singularity/tools/linaro-image-tools.git>

### Building the code

See README file within linaro-image-tools

### Creating configuration file

Hardware packs V3 use a yaml file to gather the metadata to construct
the package.

As an example we are going to add support for amd64 minnowboard
hardware.

The following configuration file named
**15.03-amd64-amd64-uefi-apertis** is used

    format: '3.0'
    initrd_file: boot/initrd.img-*
    kernel_file: boot/vmlinuz-*
    serial_tty: ttyS0
    maintainer: Apertis maintainers
    name: 15.03-amd64-amd64-uefi-apertis
    origin: Collabora
    partition_layout: apertis-uefi.yaml
    support: supported
    mmc_id: 0:0
    architectures:
    - amd64
    packages:
    - linux-image-generic
    - gummiboot
    - libegl1-mesa-drivers
    - libgles2-mesa
    assume_installed:
    - grub-pc
    - grub-pc-bin
    sources:
      apertis: https://repositories.apertis.org/apertis/ 15.03 target
    bootloaders:
      gummiboot:
       package: gummiboot
       in_boot_part: false
       extra_boot_options: quiet splash plymouth.ignore-serial-consoles

For reference, see Linaro documentation on [Hardware Packs
V3](https://wiki.linaro.org/HardwarePacksV3) syntax.

### Adding new boards into linaro-image-tools

A python class contains all default values and special proceedings to
setup specific hardware. When adding support for new hardware, one must
check if a close enough class already exist and derive from that class,
overloading only the needed methods (i.e. a new imx6 board, derive from
class
[BoardConfig](http://cgit.collabora.com/git/singularity/tools/linaro-image-tools.git/tree/linaro_image_tools/media_create/boards.py?id=c84d733688a879fbdf4034c6a53e8657618ddf20#n388)).

For the example case, on adding amd64 support, a [new board class is
defined](http://cgit.collabora.com/git/singularity/tools/linaro-image-tools.git/commit/?id=c84d733688a879fbdf4034c6a53e8657618ddf20)
and methods _make_boot_files/_make_boot_files_v2 are redefined.

### Creating first hardware pack

Use **linaro-hwpack-create** tool found in
[linaro-image-tools](https://build.collabora.co.uk/package/show?package=linaro-image-tools&project=apertis%3Ainfrastructure)

` linaro-hwpack-create --debug ${BUILDDIR:-.}/config/hwpack/"${HWPACK_CONFIG_FILE}" ${BUILDSTAMP}`

### Partition layout definition

See [partition
layouts](https://git.apertis.org/cgit/apertis-image-customization.git/tree/partition-layouts/)
in the image builder.

## Linaro's hardware pack documentation

  - [Hardware Packs](https://wiki.linaro.org/HardwarePacks)
  - [Hardware Packs V3](https://wiki.linaro.org/HardwarePacksV3)
  - [Hardware Pack
    specification](https://wiki.linaro.org/Platform/UserPlatforms/Specs/10.11/HardwarePacks)