+++
fragment = "content"
date = "2016-04-07"
weight = 100

title = "HelloWorldBundle"
+++

This document aims to describe how to create an application bundle for
Apertis using the SDK image.

## Creating a bundle from Eclipse

### Prerequisite

  - Apertis 16.03 SDK image, download from
    [here](https://images.apertis.org/daily/16.03/images/sdk/)
  - and set up in [VirtualBox]( {{< ref "/virtualbox.md" >}} )

**Note**: This documentation was tested against the 16.03 i386 images.

### Set up for using the Simulator

For the reason of license, Simulator is temporally removed on Apertis
16.03. It should be installed by manual from Apertis 15.12

### Run Eclipse

Open Eclipse. You will need to select a workspace if you have not run it
before. On Apertis 16.03, several Eclipse plugins are missing so they
should be installed by //Help// -\> //Install New Software//.

#### Install JET Plugin

Add update manager URLs listed below.

1.  Juno - <http://download.eclipse.org/releases/juno>
2.  EMF - <http://download.eclipse.org/modeling/emf/updates/releases/>
3.  M2T - <http://download.eclipse.org/modeling/m2t/updates/releases/>

Then, install *M2T JET SDK 1.1.1* -\> *Java Emitter Templates (JET)*

#### Install Autotools Plugin

If Eclipse Mars repository URL is not registered in update manager,
please add it first.

1.  Eclipse Juno repository -
    <http://download.eclipse.org/releases/juno>

Then, install *C/C++ Autotools Support*.

Now Eclipse is ready to create a project, select the *Mildenhall
Project* button in the middle of header menu of Eclipse to start the
project creation wizard.

![<File:0001> eclipse mildenhall
project.png](/images/0001_eclipse_mildenhall_project.png)

### Use the project wizard

1.  Select *Create new project*, then press the *Next* button.
2.  Enter an *Application Name* into the wizard
3.  Enter an *Bundle ID* (less than 64 characters including Application
    Name), then press the *Next* button.
4.  The *Application Type Selection* wizard window will open. Press the
    *Configure* button.
    You can add the other types of application here using the *Add*
    button. The supported types are;
      - APPLICATION
      - SERVICE
      - AGENT-SERVICE
      - EXT-APPLICATION
    However, only the *APPLICATION* type is supported at this time. For
    more details, please refer to
    [HelloWorldBundle\#Limitations]( {{< ref "/helloworldbundle.md#limitations" >}} ).
    ![none|320px|](/images/0004_application_type_selection_with_box.png)
5.  The details of the bundle configuration can be modified on
    *APPLICATION: Manifest Configuration Wizard* window. Press *Next* to
    continue once you have finished configuring the application.
    ![none|320px|](/images/0005_application_type_configuration.png)
6.  Configure the resources on the *Resource Configuration Page*, then
    press the *Finish* button.
    ![none|320px](/images/0006_resource_configuration.png)
7.  You will now return to the *Application Type Selection* window,
    press *Finish* to complete the application setup.

### Installing a bundle

Once the bundle creation is completed in the wizard, Eclipse will start
compiling it automatically.

Open a terminal to finish the remaining steps to install the bundle for
running in the Simulator after changing to application source code
directory:

    $ cd path/workspace/HelloWorld
    $ make
    $ sudo make install
    $ sudo make install-app2simu

## Running a bundle

Now, the bundle is ready to run with the Apertis Simulator. We have
several options for running the Apertis Simulator:

  - Command line:
        $ Start_Simulator.sh
  - Eclipse Icon:
    ![none|240px](/images/simulator_button.png)

If the deployment process is done successfully, *HELLOWORLD* menu is
shown in simulator screen.

![none|320px](/images/0007_simulator.png)

## Limitations

The current Mildenhall plugin for Eclipse has some limitations that you
should be aware of:

  - It does not support creating a project from the *Project Explorer*
    context menu (*Project Explorer* \> right button click \> *New* \>
    *Project* menu).
  - You can edit the configuration of an existing project only through
    the wizard. The Project menu does not support Mildenhall projects at
    this time.
  - Default application type is selected as *APPLICATION*, and it can
    not be removed. In addition, if the other type is added,
    *autogen.sh* fails:
        configure.ac:129: error: `resources/views/view1/Makefile' is already registered with AC_CONFIG_FILES.
        ../../lib/autoconf/status.m4:288: AC_CONFIG_FILES is expanded from...
        configure.ac:129: the top level
  - Do not modify *Menu Entry* \> *Menu Title* on *Application: Manifest
    configuration wizard*. Due to a character encoding problem, it will
    not be recognized by the Simulator if it is changed.
  - Due to SDK permission policy, *make install* and *make
    install-app2simu* are not supported in the Eclipse environment. They
    should be run from a terminal as root (for example, using the *sudo*
    command).
    **Alternative**: To use the macro in the Eclipse environment, we can
    change permissions of the target directory, */Applications*:
        sudo chown user -R /Applications
    Then, the bundle can be installed by running the Eclipse macro,
    *Make Targets* \> *Build* \> *install-app2simu*
    **Note**: it is not recommended because Apertis is designed for
    multi-user environment. Although this works for a specific bundle,
    it can cause other problems.