+++
fragment = "content"
date = "2014-12-18"
weight = 100

title = "QA Test Cases dbus-dos-match-rules"
+++

{{ TestCase | id = dbus-dos-match-rules | type = Performance |
execution_type = Manual | lava = N/A | image = Any | target = Any |
state = Final | description = The test enables the Stats interface in
dbus-daemon (see [upstream bug
\#80759](https://bugs.freedesktop.org/show_bug.cgi?id=80759)) and calls
GetConnectionMatchRules (see [upstream bug
\#24307](https://bugs.freedesktop.org/show_bug.cgi?id=24307)) to get the
D-Bus match rules registered by all D-Bus connections on the system and
session buses. Then, the test checks the presence of a few patterns
which might be bad. The script does not decide itself if a match rule is
good or bad, but just lists the patterns found. | resources = |
preconditions =   | execution = As normal user, run:

    $ /usr/share/chaiwala-tests/dbus-dos-match-rules/manual/run-test.sh

| results = The scipt should not display any error:

    >>> Test setup successfully!
    >>> Results will be in /tmp/dbus-match-rule-list-*.txt
    >>> Running test 'test_match_rules_system' ... PASS
    >>> Running test 'test_match_rules_session' ... PASS
    >>> All tests PASSED successfully!

The script says PASSED when GetConnectionMatchRules was called
successfully. The reports for the session bus and the system bus will be
in the following files:

  - /tmp/dbus-match-rule-list-session.txt
  - /tmp/dbus-match-rule-list-system.txt

It is necessary to analyse the reports. They will list the match rules
with the following patterns:

1.  **Match rules on the org.freedesktop.DBus.Local interface**: they
    are harmless, but they don't do anything: the [D-Bus
    specification](http://dbus.freedesktop.org/doc/dbus-specification.html)
    says the "special interface org.freedesktop.DBus.Local is reserved;
    implementations should not send messages with this interface, and
    the reference implementation of the bus daemon will disconnect any
    application that attempts to do so."
      - No action required: the test case should not be considered as
        failed when there are match rules with a Local interface.
2.  **Match rules without signal type**: D-Bus messages have 4 possible
    types: signals, method calls, method returns and errors. D-Bus match
    rules are normally used to catch signals since method calls, method
    returns and errors are normally routed to their destination without
    match rules. Those match rules might catch too many messages which
    are not meant to be received here. Moreover, when dbus-daemon needs
    to route a message, it finds the match rules to apply with a lookup
    table on (message type,
    interface)([bfo\#23117](https://bugs.freedesktop.org/show_bug.cgi?id=23117)).
    So it is more efficient to have match rules with message type and
    interface.
      - If the match rule does not have a type criteria, or the type
        criteria is not type='signal', we need to check if it is what is
        intended
      - Get the sources of the application registering the match rule
        and find where the match rule is registered
      - Find the callback where messages matching the match rule are
        handled
      - Check if it handles only signals or other message types too
      - If it handles only signals, report a bug on the application
      - Known applications which legitimately register match rules
        without a type='signal' criteria are:
          - connman
3.  **Match rules without sender**: D-Bus applications should check the
    sender of messages to make sure it does not come from an unintended
    application. A common mistake is to register a match rule for bus
    driver (i.e. dbus-daemon) signals (such as NameOwnerChanged) without
    checking that such messages really come from the bus driver.
      - Match rules on NameOwnerChanged must have criteria on type,
        interface, member, path and sender as shown by the following:
        type='signal',interface='org.freedesktop.DBus',member='NameOwnerChanged',path='/org/freedesktop/DBus',sender='org.freedesktop.DBus'
      - If they don't, report a bug on the application.
      - Known applications which legitimately register match rules
        without a sender:
          - dconf (match rules with interface='ca.desrt.dconf.Writer')
      - Known applications having this issue:
          - pacrunner
          - avahi
          - ofono
          - connman
4.  **Match rules about NameOwnerChanged without arg0**:
    NameOwnerChanged is a D-Bus signal sent by dbus-daemon to inform
    that a new connection appeared on the bus or have left the bus. Most
    applications don't want to be notified for every connection joining
    and leaving the bus, but are only interested by one service. A
    common mistake is to register a match rule for NameOwnerChanged
    without specifying the specific name in arg0 or arg0namespace and
    then filtering in the callback. This causes unnecessary wake-ups and
    increase the surface for denial of service attacks. Some
    applications such as systemd legitimately needs it, but other might
    receive too much messages because of it.
      - Known applications legitimately needing NameOwnerChanged without
        arg0:
          - systemd
          - avahi
      - Known applications correctly using arg0 or arg0namespace:
          - telepathy-mission-control: the [Client
            spec](http://telepathy.freedesktop.org/spec/Client.html)
            requires to watch
            org.freedesktop.Telepathy.Client.clientname. So it registers
            the match rule
            type='signal',interface='org.freedesktop.DBus',member='NameOwnerChanged',sender='org.freedesktop.DBus',arg0namespace='org.freedesktop.Telepathy.Client'

Example of report on the system bus:

    Connection :1.15 with pid 496 '/usr/sbin/pacrunner ' (org.pacrunner): 2 match rules, 3 warnings
       - Match rule without a sender criteria:
             - type='signal',interface='org.freedesktop.DBus.Local',member='Disconnected'
             - type='signal',interface='org.freedesktop.DBus',member='NameOwnerChanged',arg0=':1.3'
       - Match rule on the org.freedesktop.DBus.Local interface:
             - type='signal',interface='org.freedesktop.DBus.Local',member='Disconnected'

Example of report on the session bus:

    Connection :1.5 with pid 555 '/usr/lib/tracker/tracker-store ' (org.freedesktop.Tracker1): 2 match rules, 2 warnings
       - Match rule on NameOwnerChanged without a arg0* criteria:
             - type='signal',interface='org.freedesktop.DBus',member='NameOwnerChanged',path='/org/freedesktop/DBus',sender='org.freedesktop.DBus'
       - Match rule without a sender criteria:
             - type='signal',interface='ca.desrt.dconf.Writer',path='/ca/desrt/dconf/Writer/user',arg0path='/org/freedesktop/tracker/store/'

| postconditions = | notes = See also
[Docs/dbus-dos]( {{< ref "/docs/dbus-dos.md" >}} ). }}